"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cli_command_1 = require("@contentstack/cli-command");
const cli_utilities_1 = require("@contentstack/cli-utilities");
const utils_1 = require("../../../utils");
class RegionSetCommand extends cli_command_1.Command {
    async run() {
        const { args, flags: regionSetFlags } = this.parse(RegionSetCommand);
        let cda = regionSetFlags.cda;
        let cma = regionSetFlags.cma;
        let name = regionSetFlags.name;
        let selectedRegion = args.region;
        if (!(cda && cma && name) && !selectedRegion) {
            selectedRegion = await utils_1.interactive.askRegions();
        }
        if (selectedRegion === 'custom') {
            const selectedCustomRegion = await utils_1.interactive.askCustomRegion();
            name = selectedCustomRegion.name;
            cda = selectedCustomRegion.cda;
            cma = selectedCustomRegion.cma;
        }
        else if (selectedRegion === 'exit') {
            this.exit();
        }
        // Custom flag will get first priority over region argument
        if (cda && cma && name) {
            try {
                let customRegion = { cda, cma, name };
                customRegion = utils_1.regionHandler.setCustomRegion(customRegion);
                cli_utilities_1.cliux.success(`Custom region has been set to ${customRegion.name}`);
                cli_utilities_1.cliux.success(`CMA HOST: ${customRegion.cma}`);
                cli_utilities_1.cliux.success(`CDA HOST: ${customRegion.cda}`);
            }
            catch (error) {
                cli_utilities_1.logger.error('failed to set the region', error);
                cli_utilities_1.cliux.error(`Failed to set region due to: ${error.message}`);
            }
        }
        else if (['NA', 'EU', 'AZURE-NA'].includes(selectedRegion)) {
            const regionDetails = utils_1.regionHandler.setRegion(selectedRegion);
            cli_utilities_1.cliux.success(`Region has been set to ${regionDetails.name}`);
            cli_utilities_1.cliux.success(`CDA HOST: ${regionDetails.cda}`);
            cli_utilities_1.cliux.success(`CMA HOST: ${regionDetails.cma}`);
        }
        else {
            cli_utilities_1.cliux.error(`Invalid region is given`);
        }
    }
}
exports.default = RegionSetCommand;
RegionSetCommand.description = 'Set region for CLI';
RegionSetCommand.flags = {
    cda: cli_command_1.flags.string({
        char: 'd',
        description: 'Custom host to set for content delivery API, if this flag is added then cma and name flags are required',
        dependsOn: ['cma', 'name'],
        parse: (0, cli_utilities_1.printFlagDeprecation)(['-d'], ['--cda']),
    }),
    cma: cli_command_1.flags.string({
        char: 'm',
        description: 'Custom host to set for content management API, , if this flag is added then cda and name flags are required',
        dependsOn: ['cda', 'name'],
        parse: (0, cli_utilities_1.printFlagDeprecation)(['-m'], ['--cma']),
    }),
    name: cli_command_1.flags.string({
        char: 'n',
        description: 'Name for the region, if this flag is added then cda and cma flags are required',
        dependsOn: ['cda', 'cma'],
    }),
};
RegionSetCommand.examples = [
    '$ csdx config:set:region',
    '$ csdx config:set:region NA',
    '$ csdx config:set:region NA',
    '$ csdx config:set:region --cma <contentstack_cma_endpoint> --cda <contentstack_cda_endpoint> --name "India"',
];
RegionSetCommand.args = [
    {
        name: 'region',
    },
];
